@@ -5,9 +5,9 @@ use warnings;
 
 use Exporter;
 our @ISA = qw(Exporter);
-our @EXPORT = qw(spawn receive msg snd quit wt snd_wt listener open_node);
+our @EXPORT = qw(spawn receive msg snd quit wt snd_wt listener open_node vpid2pid);
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 use Carp;
 use IO::Select;
@@ -36,6 +36,9 @@ my %snd              = ();
 my $ipc_loop         = 0; 
 my $quit = 0;
 
+my %vpid2pid = ();
+sub vpid2pid { my ($vpid) = @_; $vpid2pid{$vpid} }
+
 my @rcv    = ();
 my %r_bufs = ();
 my %w_bufs = ();
@@ -172,12 +175,12 @@ sub receive(&) {
 
 	foreach (@spawn) {
 		my ($vpid, $child, $parent, $spawn) = @$_;
-		
+
 		my $kid_pid = fork;
 		defined $kid_pid or die "Can't fork: $!";
 
 		unless ($kid_pid) {
-			
+
 			foreach (@spawn) {
 				close $$_[1];
 				close $$_[2] if $$_[2] ne $parent;
@@ -194,6 +197,8 @@ sub receive(&) {
 			%fh2fh    = ();
 			%snd      = ();
 
+			%vpid2pid = ();
+
 			$ipc_loop = 0;
 
 			@rcv    = ();
@@ -222,6 +227,9 @@ sub receive(&) {
 
 			exit;
 		}
+		else {
+			$vpid2pid{$vpid} = $kid_pid;
+		}
 	}
 
 
@@ -306,7 +314,7 @@ sub ipc_loop(;$$) {
 		}
 
 		my $w_sel = IO::Select->new(map { $fh2fh{$_} } keys %w_bufs);
-		
+
 		if ($DEBUG > 1) {
 			print "Select count from $self_vpid, sel->count=", $sel->count(), ", w_sel->count=", $w_sel->count(), "\n",
 				$DEBUG > 2 ? Data::Dumper::Dumper({ snd => \%snd, r_bufs => \%r_bufs, w_bufs => \%w_bufs }) : "";
@@ -384,6 +392,7 @@ sub ipc_loop(;$$) {
  				delete $r_bufs{$fh};
  				delete $w_bufs{$fh};
 				delete $fh2fh{$fh};
+				delete $vpid2pid{$vpid};
 				delete $pack{$fh};
 				delete $unpack{$fh};
 				if (my $node_vpid = $node{$fh}) {
@@ -551,6 +560,8 @@ If a process is sent a "close" or "exit" message, then any messages from it are
 
 To break receive use "quit" subroutine.
 
+The vpid2pid function accepts the vpid argument and returns OS PID. Importnat! PID will be available only after the receive subroutine is called.
+
 =head2 Dataflow programming
 
 Sometimes you may need to get additional information from other processes and only then continue the message processing. For this you may send a message with information request and then wait information getting in a proper place by subprogram wt (abbreviated "wait"), without current message processing break.
