@@ -5,9 +5,9 @@ use warnings;
 
 use Exporter;
 our @ISA = qw(Exporter);
-our @EXPORT = qw(spawn receive msg snd quit wt snd_wt listener open_node);
+our @EXPORT = qw(spawn receive msg snd quit wt snd_wt listener open_node vpid2pid);
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 use Carp;
 use Event;
@@ -33,6 +33,9 @@ my %node             = ();
 my %snd              = ();
 my $ipc_loop         = 0; 
 
+my %vpid2pid = ();
+sub vpid2pid { my ($vpid) = @_; $vpid2pid{$vpid} }
+
 my @rcv    = ();
 my %r_bufs = ();
 my %w_bufs = ();
@@ -186,12 +189,12 @@ sub receive(&) {
 
 	foreach (@spawn) {
 		my ($vpid, $child, $parent, $spawn) = @$_;
-		
+
 		my $kid_pid = fork;
 		defined $kid_pid or die "Can't fork: $!";
 
 		unless ($kid_pid) {
-			
+
 			foreach (@spawn) {
 				close $$_[1];
 				close $$_[2] if $$_[2] ne $parent;
@@ -208,6 +211,8 @@ sub receive(&) {
 			%fh2fh    = ();
 			%snd      = ();
 
+			%vpid2pid = ();
+
 			$ipc_loop = 0;
 
 			@rcv    = ();
@@ -219,7 +224,7 @@ sub receive(&) {
 
 			%closed = ();
 
-			%fh2ww = (); 
+			%fh2ww = ();
 
 			($waited_vpid, $waited_msg, @waited_rv) = ();
 
@@ -238,6 +243,9 @@ sub receive(&) {
 
 			exit;
 		}
+		else {
+			$vpid2pid{$vpid} = $kid_pid;
+		}
 	}
 
 
@@ -394,6 +402,7 @@ sub r_event_cb {
  				delete $r_bufs{$fh};
  				delete $w_bufs{$fh};
 				delete $fh2fh{$fh};
+				delete $vpid2pid{$vpid};
 				delete $pack{$fh};
 				delete $unpack{$fh};
 				if (my $node_vpid = $node{$fh}) {
